@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 """
 Author:Jy
-2020/09/09 11:56:00
+2020/11/12 12:32:00
 shanghai
 """
 import sys, os
@@ -144,7 +144,8 @@ class JyInterface(object):
                                                                        secret=self.secret,
                                                                        passphrase=self.passphrase,
                                                                        directOffset=directOffset,
-                                                                       transferId=self.transferId))
+                                                                       transferId=self.transferId,
+                                                                       futureOrSpot=self.futureOrSpot))
         return response.message
     
     def cancelOrder(self, symbol, orderId):
@@ -243,6 +244,17 @@ class JyInterface(object):
                 return output[1]
             elif x == 'short':
                 return output[2]
+    
+    def transfer(self, symbol, amount, transferType:int=2, direction:int=1):
+        response = self.stub.transfer(common_pb2.TransferRequest(type=self.type_, 
+                                                                 transferType=transferType,  # 1:币币-交割; 2:币币-永续(币本位); 3-币币-永续(USDT本位)
+                                                                 appKey=self.appKey,
+                                                                 secret=self.secret,
+                                                                 passphrase=self.passphrase,
+                                                                 symbols=symbol, 
+                                                                 direction=direction,
+                                                                 amount=amount))
+        return float(response.message)  # 是否成功; 0:成功,1:失败
 
     def run_(self):
         """let subclass inherit"""
@@ -295,4 +307,5 @@ class JyInterface(object):
                 if Exception == 'SystemExit':
                     sys.exit(0)
                 else:
-                    pass
\ No newline at end of file
+                    pass                
+            
\ No newline at end of file
